@@ -1,9 +1,5 @@
 from pollination_dsl.dag import Inputs, DAG, task, Outputs
 from dataclasses import dataclass
-from pollination.honeybee_radiance.sky import GenSky, AdjustSkyForMetric
-from pollination.honeybee_radiance.octree import CreateOctreeWithSky
-from pollination.honeybee_radiance.translate import CreateRadianceFolderGrid
-from pollination.honeybee_radiance.grid import SplitGridFolder, MergeFolderData
 from pollination.honeybee_radiance.raytrace import RayTracingPointInTime
 
 # input/output alias
@@ -14,6 +10,8 @@ from pollination.alias.inputs.grid import grid_filter_input, \
     min_sensor_count_input, cpu_count
 from pollination.alias.outputs.daylight import point_in_time_grid_results
 
+from ._prepare_folder import PointInTimeGridPrepareFolder
+from ._postprocess_results import PointInTimeGridPostProcess
 
 @dataclass
 class PointInTimeGridEntryPoint(DAG):
@@ -79,104 +77,48 @@ class PointInTimeGridEntryPoint(DAG):
         alias=rad_par_daylight_factor_input
     )
 
-    @task(template=GenSky)
-    def generate_sky(self, sky_string=sky):
+    @task(template=PointInTimeGridPrepareFolder)
+    def prepare_folder_point_in_time_grid(
+        self, model=model, sky=sky, metric=metric, grid_filter=grid_filter,
+        cpu_count=cpu_count, min_sensor_count=min_sensor_count
+    ):
         return [
             {
-                'from': GenSky()._outputs.sky,
-                'to': 'resources/weather.sky'
-            }
-        ]
-
-    @task(
-        template=AdjustSkyForMetric,
-        needs=[generate_sky]
-    )
-    def adjust_sky(self, sky=generate_sky._outputs.sky, metric=metric):
-        return [
-            {
-                'from': AdjustSkyForMetric()._outputs.adjusted_sky,
-                'to': 'resources/weather.sky'
-            }
-        ]
-
-    @task(template=CreateRadianceFolderGrid)
-    def create_rad_folder(
-        self, input_model=model, grid_filter=grid_filter
-            ):
-        """Translate the input model to a radiance folder."""
-        return [
-            {
-                'from': CreateRadianceFolderGrid()._outputs.model_folder,
+                'from': PointInTimeGridPrepareFolder()._outputs.model_folder,
                 'to': 'model'
             },
             {
-                'from': CreateRadianceFolderGrid()._outputs.bsdf_folder,
-                'to': 'model/bsdf'
+                'from': PointInTimeGridPrepareFolder()._outputs.resources,
+                'to': 'resources'
             },
             {
-                'from': CreateRadianceFolderGrid()._outputs.model_sensor_grids_file,
-                'to': 'results/pit/grids_info.json'
+                'from': PointInTimeGridPrepareFolder()._outputs.initial_results,
+                'to': 'initial_results'
             },
             {
-                'from': CreateRadianceFolderGrid()._outputs.sensor_grids,
-                'description': 'Sensor grids information.'
-            }
-        ]
-
-    @task(
-        template=CreateOctreeWithSky, needs=[adjust_sky, create_rad_folder]
-    )
-    def create_octree(
-        self, model=create_rad_folder._outputs.model_folder,
-        sky=adjust_sky._outputs.adjusted_sky
-    ):
-        """Create octree from radiance folder and sky."""
-        return [
-            {
-                'from': CreateOctreeWithSky()._outputs.scene_file,
-                'to': 'resources/scene.oct'
-            }
-        ]
-
-    @task(
-        template=SplitGridFolder, needs=[create_rad_folder],
-        sub_paths={'input_folder': 'grid'}
-    )
-    def split_grid_folder(
-        self, input_folder=create_rad_folder._outputs.model_folder,
-        cpu_count=cpu_count, cpus_per_grid=1, min_sensor_count=min_sensor_count
-    ):
-        """Split sensor grid folder based on the number of CPUs"""
-        return [
-            {
-                'from': SplitGridFolder()._outputs.output_folder,
-                'to': 'resources/grid'
-            },
-            {
-                'from': SplitGridFolder()._outputs.dist_info,
-                'to': 'initial_results/_redist_info.json'
-            },
-            {
-                'from': SplitGridFolder()._outputs.sensor_grids,
-                'description': 'Sensor grids information.'
+                'from': PointInTimeGridPrepareFolder()._outputs.sensor_grids,
+                'description': 'Grid information.'
             }
         ]
 
     @task(
         template=RayTracingPointInTime,
-        needs=[create_rad_folder, split_grid_folder, create_octree],
-        loop=split_grid_folder._outputs.sensor_grids,
+        needs=[prepare_folder_point_in_time_grid],
+        loop=prepare_folder_point_in_time_grid._outputs.sensor_grids,
         sub_folder='initial_results/{{item.full_id}}',  # subfolder for each grid
-        sub_paths={'grid': '{{item.full_id}}.pts'}  # subpath for sensor_grid
+        sub_paths={
+            'grid': 'grid/{{item.full_id}}.pts',
+            'scene_file': 'scene.oct',
+            'bsdf_folder': 'bsdf'
+        }
     )
     def point_in_time_grid_ray_tracing(
         self,
         radiance_parameters=radiance_parameters,
         metric=metric,
-        scene_file=create_octree._outputs.scene_file,
-        grid=split_grid_folder._outputs.output_folder,
-        bsdf_folder=create_rad_folder._outputs.bsdf_folder
+        scene_file=prepare_folder_point_in_time_grid._outputs.resources,
+        grid=prepare_folder_point_in_time_grid._outputs.resources,
+        bsdf_folder=prepare_folder_point_in_time_grid._outputs.model_folder
     ):
         return [
             {
@@ -186,14 +128,17 @@ class PointInTimeGridEntryPoint(DAG):
         ]
 
     @task(
-        template=MergeFolderData,
+        template=PointInTimeGridPostProcess,
         needs=[point_in_time_grid_ray_tracing]
     )
-    def restructure_results(self, input_folder='initial_results', extension='res'):
+    def post_process_point_in_time_grid(
+        self, results_folder='initial_results',
+        grids_info='resources/grids_info.json'
+    ):
         return [
             {
-                'from': MergeFolderData()._outputs.output_folder,
-                'to': 'results/pit'
+                'from': PointInTimeGridPostProcess()._outputs.results,
+                'to': 'results'
             }
         ]
 
